from datetime import datetime
from network import PerfNetwork

class PerfMiddleware(object):
    PERF_INGEST_URL = "https://data.perf.sh/ingest"

    def process_request(self, request):
        request._perf_request_time = datetime.now()

    def process_template_response(self, request, response):
        response_time = datetime.now() - request._perf_request_time
        payload = [{
            "request_url": request.build_absolute_uri(),
            "request_method": request.method,
            "status_code": response.status_code,
            "time_in_millis": int(round(response_time.microseconds / 1000, 0)),
            "normalized_uri": self.build_normalized_uri(request)
        }]
        PerfNetwork.send_requests(payload)
        return response

    def build_normalized_uri(self, request):
        normalized_uri = request.path
        for key, value in request.resolver_match.kwargs.iteritems():
            return normalized_uri.replace(value, ":%s" % key, 1)
        return normalized_uri



from perf import Perf
import requests

class PerfNetwork(object):
    PERF_INGEST_URL = "https://data.perf.sh/ingest"

    @staticmethod
    def send_requests(payload):
        api_key = Perf.get_api_key()
        if api_key != None:
            headers = {
                "X-Perf-Public-API-Key": api_key,
                "Content-Type": "application/json",
                "User-Agent": "PerfAgent-Django/0.1.1"
            }
            requests.post(PerfNetwork.PERF_INGEST_URL, json=payload, headers=headers)



import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-perf',
    version='0.1.1',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    include_package_data=True,
    license='LGPL-3.0',
    description='A simple Django Middleware for sending request data to Perf.',
    long_description=README,
    url='https://github.com/perflabs/django-perf',
    author='Jonathan Grana',
    author_email='john@perf.sh',
    classifiers=[],
)



from django.conf import settings

class Perf(object):

    @staticmethod
    def get_api_key():
        perf_settings = getattr(settings, "PERF_CONFIG", None)
        if perf_settings != None:
            return perf_settings.get("api_key", None)
        return None
